@@ -24,7 +24,13 @@
 #include <KFilePlacesModel>
 #include <KHistoryComboBox>
 #include <KIO/ApplicationLauncherJob>
+#include <kio_version.h>
+#include <kwidgetsaddons_version.h>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+#include <KIO/JobUiDelegateFactory>
+#else
 #include <KIO/JobUiDelegate>
+#endif
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KSharedConfig>
@@ -157,7 +163,11 @@ void KateFileBrowser::setupToolbar()
         if (it == QLatin1String("bookmarks") || it == QLatin1String("sync_dir") || it == QLatin1String("configure")) {
             ac = actionCollection()->action(it);
         } else {
+#if KIO_VERSION < QT_VERSION_CHECK(5, 100, 0)
             ac = m_dirOperator->actionCollection()->action(it);
+#else
+            ac = m_dirOperator->action(actionFromName(it));
+#endif
         }
 
         if (ac) {
@@ -190,6 +200,41 @@ void KateFileBrowser::writeSessionConfig(KConfigGroup &cg)
     cg.writeEntry("filter history", m_filter->historyItems());
 }
 
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+KDirOperator::Action KateFileBrowser::actionFromName(const QString &name)
+{
+    if (name == QLatin1String("up")) {
+        return KDirOperator::Up;
+    } else if (name == QLatin1String("back")) {
+        return KDirOperator::Back;
+    } else if (name == QLatin1String("forward")) {
+        return KDirOperator::Forward;
+    } else if (name == QLatin1String("home")) {
+        return KDirOperator::Home;
+    } else if (name == QLatin1String("reload")) {
+        return KDirOperator::Reload;
+    } else if (name == QLatin1String("mkdir")) {
+        return KDirOperator::NewFolder;
+    } else if (name == QLatin1String("delete")) {
+        return KDirOperator::Delete;
+    } else if (name == QLatin1String("short view")) {
+        return KDirOperator::ShortView;
+    } else if (name == QLatin1String("detailed view")) {
+        return KDirOperator::DetailedView;
+    } else if (name == QLatin1String("tree view")) {
+        return KDirOperator::TreeView;
+    } else if (name == QLatin1String("detailed tree view")) {
+        return KDirOperator::DetailedTreeView;
+    } else if (name == QLatin1String("show hidden")) {
+        return KDirOperator::ShowHiddenFiles;
+    } else {
+        qWarning() << "Unknown KDirOperator action:" << name;
+    }
+
+    return {};
+}
+#endif
+
 // END Public Methods
 
 // BEGIN Public Slots
@@ -292,7 +337,11 @@ void KateFileBrowser::openWithMenuAction(QAction *a)
     // If app is null, ApplicationLauncherJob will invoke the open-with dialog
     auto *job = new KIO::ApplicationLauncherJob(app);
     job->setUrls(list);
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+#else
     job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+#endif
     job->start();
 }
 // END Public Slots
@@ -309,12 +358,21 @@ void KateFileBrowser::openSelectedFiles()
     const KFileItemList list = m_dirOperator->selectedItems();
 
     if (list.count() > 20) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (KMessageBox::questionTwoActions(
+                this,
+#else
         if (KMessageBox::questionYesNo(this,
-                                       i18np("You are trying to open 1 file, are you sure?", "You are trying to open %1 files, are you sure?", list.count()),
-                                       {},
-                                       KGuiItem(i18nc("@action:button", "Open All Files"), QStringLiteral("document-open")),
-                                       KStandardGuiItem::cancel())
+#endif
+                i18np("You are trying to open 1 file, are you sure?", "You are trying to open %1 files, are you sure?", list.count()),
+                {},
+                KGuiItem(i18nc("@action:button", "Open All Files"), QStringLiteral("document-open")),
+                KStandardGuiItem::cancel())
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            == KMessageBox::SecondaryAction) {
+#else
             == KMessageBox::No) {
+#endif
             return;
         }
     }
@@ -393,12 +451,21 @@ void KateFileBrowser::setupActions()
     // section for settings menu
     KActionMenu *optionsMenu = new KActionMenu(QIcon::fromTheme(QStringLiteral("configure")), i18n("Options"), this);
     optionsMenu->setPopupMode(QToolButton::InstantPopup);
+#if KIO_VERSION < QT_VERSION_CHECK(5, 100, 0)
     optionsMenu->addAction(m_dirOperator->actionCollection()->action(QStringLiteral("short view")));
     optionsMenu->addAction(m_dirOperator->actionCollection()->action(QStringLiteral("detailed view")));
     optionsMenu->addAction(m_dirOperator->actionCollection()->action(QStringLiteral("tree view")));
     optionsMenu->addAction(m_dirOperator->actionCollection()->action(QStringLiteral("detailed tree view")));
     optionsMenu->addSeparator();
     optionsMenu->addAction(m_dirOperator->actionCollection()->action(QStringLiteral("show hidden")));
+#else
+    optionsMenu->addAction(m_dirOperator->action(KDirOperator::ShortView));
+    optionsMenu->addAction(m_dirOperator->action(KDirOperator::DetailedView));
+    optionsMenu->addAction(m_dirOperator->action(KDirOperator::TreeView));
+    optionsMenu->addAction(m_dirOperator->action(KDirOperator::DetailedTreeView));
+    optionsMenu->addSeparator();
+    optionsMenu->addAction(m_dirOperator->action(KDirOperator::ShowHiddenFiles));
+#endif
 
     // action for synchronising the dir operator with the current document path...
     m_autoSyncFolder = new QAction(this);
@@ -434,7 +501,11 @@ void KateFileBrowser::setupActions()
     for (QAction *a : actions) {
         a->setShortcut(QKeySequence());
     }
+#if KIO_VERSION < QT_VERSION_CHECK(5, 100, 0)
     const auto dirActions = m_dirOperator->actionCollection()->actions();
+#else
+    const auto dirActions = m_dirOperator->allActions();
+#endif
     for (QAction *a : dirActions) {
         a->setShortcut(QKeySequence());
     }
