@@ -9,7 +9,6 @@
 
 #include "gitblametooltip.h"
 
-#include <KTextEditor/ConfigPage>
 #include <KTextEditor/InlineNoteProvider>
 #include <KTextEditor/MainWindow>
 #include <KTextEditor/Plugin>
@@ -20,7 +19,8 @@
 #include <QHash>
 #include <QList>
 #include <QLocale>
-#include <QRegularExpression>
+#include <QPointer>
+#include <QTimer>
 #include <QVariant>
 #include <QVector>
 
@@ -90,12 +90,10 @@ public:
 
     void showCommitTreeView(const QUrl &url);
 
-    Q_SIGNAL void message(const QVariantMap &);
-
 private:
     void sendMessage(const QString &text, bool error);
 
-    void viewChanged(KTextEditor::View *view);
+    void startGitBlameForActiveView();
 
     void startBlameProcess(const QUrl &url);
     void blameFinished(int exitCode, QProcess::ExitStatus exitStatus);
@@ -106,7 +104,7 @@ private:
     void createToolView();
     void hideToolView();
 
-    void showDiffForFile(const QByteArray &diffContents);
+    void showDiffForFile(const QByteArray &diffContents, const QString &file);
 
     const CommitInfo &blameGetUpdateInfo(int lineNr);
 
@@ -126,6 +124,7 @@ private:
     class CommitDiffTreeView *m_commitFilesView;
     std::unique_ptr<QWidget> m_toolView;
     QPointer<KTextEditor::View> m_diffView;
+    QTimer m_startBlameTimer;
 };
 
 #endif // KateGitBlamePlugin_h
