@@ -36,7 +36,6 @@
 #include <QKeyEvent>
 #include <QMenu>
 #include <QPoint>
-#include <QScrollBar>
 
 #include <ktexteditor_utils.h>
 
@@ -293,7 +292,7 @@ KatePluginSearchView::KatePluginSearchView(KTextEditor::Plugin *plugin, KTextEdi
     , m_kateApp(application)
     , m_mainWindow(mainWin)
 {
-    KXMLGUIClient::setComponentName(QStringLiteral("katesearch"), i18n("Kate Search & Replace"));
+    KXMLGUIClient::setComponentName(QStringLiteral("katesearch"), i18n("Search & Replace"));
     setXMLFile(QStringLiteral("ui.rc"));
 
     m_toolView = mainWin->createToolView(plugin,
@@ -339,7 +338,7 @@ KatePluginSearchView::KatePluginSearchView(KTextEditor::Plugin *plugin, KTextEdi
     connect(a, &QAction::triggered, this, &KatePluginSearchView::openSearchView);
 
     a = actionCollection()->addAction(QStringLiteral("search_in_files_new_tab"));
-    a->setText(i18n("Find in Files (in new tab)"));
+    a->setText(i18n("Find in Files (in a New Tab)"));
     // first add tab, then open search view, since open search view switches to show the search options
     connect(a, &QAction::triggered, this, &KatePluginSearchView::addTab);
     connect(a, &QAction::triggered, this, &KatePluginSearchView::openSearchView);
@@ -952,6 +951,13 @@ void KatePluginSearchView::startSearch()
         return;
     }
 
+    KTextEditor::View *activeView = m_mainWindow->activeView();
+    QList<KTextEditor::Document *> documents;
+    if ((m_ui.searchPlaceCombo->currentIndex() == MatchModel::CurrentFile && !activeView)
+        || (m_ui.searchPlaceCombo->currentIndex() == MatchModel::OpenFiles && m_kateApp->documents().isEmpty())) {
+        return;
+    }
+
     m_isSearchAsYouType = false;
 
     QString currentSearchText = m_ui.searchCombo->currentText();
@@ -987,7 +993,7 @@ void KatePluginSearchView::startSearch()
         patternOptions |= QRegularExpression::CaseInsensitiveOption;
     }
 
-    if (pattern.contains(QLatin1String("\\n"))) {
+    if (m_ui.useRegExp->isChecked() && pattern.contains(QLatin1String("\\n"))) {
         patternOptions |= QRegularExpression::MultilineOption;
     }
     QRegularExpression reg(pattern, patternOptions);
@@ -1043,10 +1049,10 @@ void KatePluginSearchView::startSearch()
     if (m_ui.searchPlaceCombo->currentIndex() == MatchModel::CurrentFile) {
         m_resultBaseDir.clear();
         QList<KTextEditor::Document *> documents;
-        KTextEditor::View *activeView = m_mainWindow->activeView();
         if (activeView) {
             documents << activeView->document();
         }
+
         m_searchOpenFiles.startSearch(documents, reg);
     } else if (m_ui.searchPlaceCombo->currentIndex() == MatchModel::OpenFiles) {
         m_resultBaseDir.clear();
@@ -1166,7 +1172,7 @@ void KatePluginSearchView::startSearchWhileTyping()
     if (!m_ui.matchCase->isChecked()) {
         patternOptions |= QRegularExpression::CaseInsensitiveOption;
     }
-    if (pattern.contains(QLatin1String("\\n"))) {
+    if (m_curResults->useRegExp && pattern.contains(QLatin1String("\\n"))) {
         patternOptions |= QRegularExpression::MultilineOption;
     }
     QRegularExpression reg(pattern, patternOptions);
@@ -1666,12 +1672,13 @@ void KatePluginSearchView::itemSelected(const QModelIndex &item)
 
     // open any children to go to the first match in the file
     QModelIndex matchItem = item;
-    while (m_curResults->model()->hasChildren(matchItem)) {
-        matchItem = m_curResults->model()->index(0, 0, matchItem);
+    if (item.model() == m_curResults->model()) {
+        while (m_curResults->model()->hasChildren(matchItem)) {
+            matchItem = m_curResults->model()->index(0, 0, matchItem);
+        }
+        m_curResults->treeView->setCurrentIndex(matchItem);
     }
 
-    m_curResults->treeView->setCurrentIndex(matchItem);
-
     // get stuff
     int toLine = matchItem.data(MatchModel::StartLineRole).toInt();
     int toColumn = matchItem.data(MatchModel::StartColumnRole).toInt();
@@ -1988,6 +1995,7 @@ void KatePluginSearchView::addTab()
     res->treeView->setRootIsDecorated(false);
     connect(res->treeView, &QTreeView::doubleClicked, this, &KatePluginSearchView::itemSelected, Qt::UniqueConnection);
     connect(res->treeView, &QTreeView::customContextMenuRequested, this, &KatePluginSearchView::customResMenuRequested, Qt::UniqueConnection);
+    connect(res, &Results::requestDetachToMainWindow, this, &KatePluginSearchView::detachTabToMainWindow, Qt::UniqueConnection);
     res->matchModel.setDocumentManager(m_kateApp);
     connect(&res->matchModel, &MatchModel::replaceDone, this, &KatePluginSearchView::replaceDone);
 
@@ -2009,6 +2017,24 @@ void KatePluginSearchView::addTab()
     res->treeView->installEventFilter(this);
 }
 
+void KatePluginSearchView::detachTabToMainWindow(Results *res)
+{
+    if (!res) {
+        return;
+    }
+
+    int i = m_tabBar->currentIndex();
+    res->setWindowIcon(QIcon::fromTheme(QStringLiteral("edit-find")));
+    res->setWindowTitle(i18n("Search: %1", m_tabBar->tabText(i)));
+    Utils::addWidget(res, m_mainWindow);
+    if (res == m_curResults) {
+        m_curResults = nullptr;
+    }
+    res->isDetachedToMainWindow = true;
+    m_tabBar->removeTab(i);
+    addTab();
+}
+
 void KatePluginSearchView::tabCloseRequested(int index)
 {
     Results *tmp = qobject_cast<Results *>(m_ui.resultWidget->widget(index));
@@ -2143,6 +2169,14 @@ void KatePluginSearchView::customResMenuRequested(const QPoint &pos)
         menu->addAction(exportMatches);
     }
 
+    if (m_curResults) {
+        QAction *openAsEditorTab = new QAction(i18n("Open as Editor Tab"), tree);
+        connect(openAsEditorTab, &QAction::triggered, this, [this] {
+            detachTabToMainWindow(m_curResults);
+        });
+        menu->addAction(openAsEditorTab);
+    }
+
     QAction *clear = menu->addAction(i18n("Clear"));
 
     menu->popup(tree->viewport()->mapToGlobal(pos));
