@@ -12,7 +12,6 @@
 #include <kcoreaddons_version.h>
 
 #include <KAboutData>
-#include <KConfigGroup>
 #include <KConfigGui>
 #include <KCrash>
 #include <KLocalizedString>
@@ -148,6 +147,7 @@ void KateApp::fillAuthorsAndCredits(KAboutData &aboutData)
     aboutData.addAuthor(i18n("Dominik Haumann"), i18n("Core Developer"), QStringLiteral("dhaumann@kde.org"));
     aboutData.addAuthor(i18n("Sven Brauch"), i18n("Developer"), QStringLiteral("mail@svenbrauch.de"));
     aboutData.addAuthor(i18n("Kåre Särs"), i18n("Developer"), QStringLiteral("kare.sars@iki.fi"));
+    aboutData.addAuthor(i18n("Waqar Ahmed"), i18n("Core Developer"), QStringLiteral("waqar.17a@gmail.com"));
     aboutData.addAuthor(i18n("Anders Lund"), i18n("Core Developer"), QStringLiteral("anders@alweb.dk"), QStringLiteral("https://www.alweb.dk"));
     aboutData.addAuthor(i18n("Joseph Wenninger"),
                         i18n("Core Developer"),
@@ -657,3 +657,13 @@ void KateApp::remoteMessageReceived(quint32, QByteArray message)
         activeMainWindow()->activateView(doc);
     }
 }
+
+bool KateApp::documentVisibleInOtherWindows(KTextEditor::Document *doc, KateMainWindow *window) const
+{
+    for (auto win : m_mainWindows) {
+        if (win != window && win->viewManager()->viewspaceCountForDoc(doc) > 0) {
+            return true;
+        }
+    }
+    return false;
+}
