@@ -13,10 +13,10 @@
 #include <ktexteditor/modificationinterface.h>
 #include <ktexteditor/view.h>
 
+#include "doc_or_widget.h"
 #include "kateprivate_export.h"
 #include "katetabbar.h"
 
-#include <QHash>
 #include <QWidget>
 
 class KConfigBase;
@@ -29,6 +29,9 @@ class KATE_PRIVATE_EXPORT KateViewSpace : public QWidget
 {
     Q_OBJECT
 
+    friend class LocationHistoryTest;
+    friend class KateViewManagementTests;
+
 public:
     explicit KateViewSpace(KateViewManager *, QWidget *parent = nullptr, const char *name = nullptr);
 
@@ -48,7 +51,7 @@ public:
     /**
      * @return the view manager that this viewspace belongs to
      */
-    KateViewManager *viewManger() const
+    KateViewManager *viewManager() const
     {
         return m_viewManager;
     }
@@ -65,7 +68,7 @@ public:
     {
         return showView(view->document());
     }
-    bool showView(KTextEditor::Document *document);
+    bool showView(DocOrWidget);
 
     // might be nullptr, if there is no view
     KTextEditor::View *currentView();
@@ -77,11 +80,16 @@ public:
      * Returns the document list of this tab bar.
      * @return document list in order of tabs
      */
-    QVector<KTextEditor::Document *> documentList() const
+    QVector<DocOrWidget> documentList() const
     {
         return m_tabBar->documentList();
     }
 
+    int tabCount() const
+    {
+        return m_tabBar->count();
+    }
+
     /**
      * How many documents are registered here?
      */
@@ -104,20 +112,20 @@ public:
     /*
      * Does this viewspace contain @p doc
      */
-    bool hasDocument(KTextEditor::Document *doc) const;
+    bool hasDocument(DocOrWidget doc) const;
 
     /**
      * Removes @p doc from this space and returns the associated
-     * view
+     * view or a widget
      * Used for dnd
      */
-    KTextEditor::View *takeView(KTextEditor::Document *doc);
+    QWidget *takeView(DocOrWidget);
 
     /**
      * Adds @p view to this space
      * Used for dnd to add a view from another viewspace
      */
-    void addView(KTextEditor::View *v);
+    void addView(QWidget *w);
 
     /**
      * Event filter to catch events from view space tool buttons.
@@ -153,7 +161,12 @@ public:
      */
     QWidget *currentWidget();
 
-    void closeTabWithWidget(QWidget *widget);
+    /// Returns all non-KTE::View widgets
+    QWidgetList widgets() const;
+
+    bool closeTabWithWidget(QWidget *widget);
+
+    bool activateWidget(QWidget *widget);
 
     // BEGIN Location History Stuff
 
@@ -186,6 +199,13 @@ public:
 
     void focusNavigationBar();
 
+    // ensure we have a view for the current document tab, e.g. after document closing
+    void ensureViewForCurrentTab()
+    {
+        // just trigger change view, will do the needful
+        changeView(m_tabBar->currentIndex());
+    }
+
 protected:
     // DND
     void dragEnterEvent(QDragEnterEvent *e) override;
@@ -240,7 +260,7 @@ private Q_SLOTS:
     /**
      * Document created or deleted, used to auto hide/show the tabs
      */
-    void documentCreatedOrDeleted(KTextEditor::Document *);
+    void updateTabBar();
 
 private:
     bool acceptsDroppedTab(const class QMimeData *tabMimeData);
@@ -290,7 +310,7 @@ private:
      * tab in the KateTabBar
      * these are stored in used order (MRU last)
      */
-    QVector<KTextEditor::Document *> m_registeredDocuments;
+    QVector<DocOrWidget> m_registeredDocuments;
 
     // the list of views that are contained in this view space,
     // mapped through a hash from Document to View.
@@ -322,8 +342,6 @@ private:
         class QVBoxLayout *mainLayout = nullptr;
     } m_layout;
 
-    friend class LocationHistoryTest;
-
     // should the tab bar be auto hidden if just one document is open?
     bool m_autoHideTabBar = false;
 };
